==> nextcloud-app-deck-1:1.15.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/ia.js <==
OC.L10N.register(
    "deck",
    {
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Le file incargate excede le directiva MAX_FILE_SIZE que esseva specificate in le formulario HTML",
    "No file was uploaded" : "Nulle file esseva incargate",
    "Missing a temporary folder" : "Il manca un dossier temporari",
    "Finished" : "Finite",
    "To review" : "A revider",
    "Action needed" : "Action necessari",
    "Later" : "Depost",
    "Done" : "Preste",
    "Attachments" : "Attachamentos",
    "Cancel" : "Cancellar",
    "Completed" : "Completate",
    "Details" : "Detalios",
    "Sharing" : "Compartente",
    "Tags" : "Etiquettas",
    "Activity" : "Activitate",
    "Undo" : "Disfacer",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Owner" : "Owner",
    "Delete" : "Deler",
    "Edit" : "Modificar",
    "Members" : "Membros",
    "Download" : "Discargar",
    "Modified" : "Modificate",
    "Comments" : "Commentarios",
    "Save" : "Salveguardar",
    "Created:" : "Create:",
    "Reply" : "Responder",
    "Update" : "Actualisation",
    "Description" : "Description",
    "(group)" : "(gruppo)",
    "seconds ago" : "secundas passate",
    "Keyboard shortcuts" : "Combinationes de claves",
    "Keyboard shortcut" : "Combination de claves",
    "Search" : "Cercar",
    "Shared with you" : "Compartite con te",
    "No notifications" : "Nulle notificationes",
    "Advanced options" : "Optiones avantiate",
    "Export" : "Exportar",
    "Today" : "Hodie",
    "Tomorrow" : "Deman",
    "Close" : "Clauder",
    "Share" : "Compartir",
    "Personal" : "Personal"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-deck-1:1.16.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/ia.js <==
OC.L10N.register(
    "deck",
    {
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Le file incargate excede le directiva MAX_FILE_SIZE que esseva specificate in le formulario HTML",
    "No file was uploaded" : "Nulle file esseva incargate",
    "Missing a temporary folder" : "Il manca un dossier temporari",
    "Finished" : "Finite",
    "To review" : "A revider",
    "Action needed" : "Action necessari",
    "Later" : "Depost",
    "Done" : "Preste",
    "Attachments" : "Attachamentos",
    "Cancel" : "Cancellar",
    "Completed" : "Completate",
    "Details" : "Detalios",
    "Sharing" : "Compartente",
    "Tags" : "Etiquettas",
    "Activity" : "Activitate",
    "Undo" : "Disfacer",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Owner" : "Owner",
    "Delete" : "Deler",
    "Edit" : "Modificar",
    "Members" : "Membros",
    "Download" : "Discargar",
    "Modified" : "Modificate",
    "Comments" : "Commentarios",
    "Save" : "Salveguardar",
    "Created:" : "Create:",
    "Reply" : "Responder",
    "Update" : "Actualisation",
    "Description" : "Description",
    "(group)" : "(gruppo)",
    "seconds ago" : "secundas passate",
    "Keyboard shortcuts" : "Combinationes de claves",
    "Keyboard shortcut" : "Combination de claves",
    "Search" : "Cercar",
    "Shared with you" : "Compartite con te",
    "No notifications" : "Nulle notificationes",
    "Advanced options" : "Optiones avantiate",
    "Export" : "Exportar",
    "Close" : "Clauder",
    "Share" : "Compartir",
    "Personal" : "Personal",
    "Today" : "Hodie",
    "Tomorrow" : "Deman"
},
"nplurals=2; plural=(n != 1);");
